@@ -25,7 +25,8 @@ def publish(topic, body=None, path=None, json_encoder=None) -> None:
     message = json.dumps(message, cls=json_encoder)
     message = json.dumps({"default": message})
 
-    topic_arn = f'{settings.AWS_SNS_PATH}{settings.ENVIRONMENT}-{topic}'
+    env = 'dev' if settings.ENVIRONMENT == 'local' else settings.ENVIRONMENT
+    topic_arn = f'{settings.AWS_SNS_PATH}{env}-{topic}'
     print('SNS publishing:', topic_arn, message)
     resp = client.publish(
         TopicArn=topic_arn,
